join

package
v0.0.0-...-43fb0ae Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 15, 2026 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Rendered for windows/amd64

Overview

Package join provides functions for domain joining a Windows client to a domain.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Domain

func Domain(domain, joinOU, joinAccount, joinPassword string, options DomainJoinOptions) error

Domain joins the local machine to a domain. See https://learn.microsoft.com/en-us/windows/win32/api/lmjoin/nf-lmjoin-netjoindomain for more details.

Types

type DomainJoinOptions

type DomainJoinOptions uint32

DomainJoinOptions specifies options for the domain join operation. See https://learn.microsoft.com/en-us/windows/win32/api/lmjoin/nf-lmjoin-netjoindomain

const (
	// JoinDomainFlag joins the domain specified in lpDomain.
	JoinDomainFlag DomainJoinOptions = 0x00000001
	// AcctCreate indicates that the caller will create the account on the domain.
	AcctCreate DomainJoinOptions = 0x00000002
	// AcctDelete indicates that lpAccount specifies an account to be deleted during an unjoin operation.
	AcctDelete DomainJoinOptions = 0x00000004
	// Win9XUpgrade indicates the join is part of a Win9x upgrade.
	Win9XUpgrade DomainJoinOptions = 0x00000010
	// DomainJoinIfJoined causes NetJoinDomain to function even if the workstation is already joined to lpDomain.
	DomainJoinIfJoined DomainJoinOptions = 0x00000020
	// JoinUnsecure performs an unsecure join.
	JoinUnsecure DomainJoinOptions = 0x00000040
	// MachinePwdPassed indicates that the machine password is being passed.
	MachinePwdPassed DomainJoinOptions = 0x00000080
	// DeferSpnSet defers setting the SPN.
	DeferSpnSet DomainJoinOptions = 0x00000100
	// JoinDCAccount performs a join as a DC account.
	JoinDCAccount DomainJoinOptions = 0x00000200
	// JoinWithNewName performs a join with a new name.
	JoinWithNewName DomainJoinOptions = 0x00000400
	// InstallInvocation indicates an install invocation.
	InstallInvocation DomainJoinOptions = 0x00001000
	// IgnoreUnsupportedFlags ignores unsupported flags.
	IgnoreUnsupportedFlags DomainJoinOptions = 0x10000000
)

Jump to